@@ -50,12 +50,16 @@ class ProjectTest(unittest.TestCase):
         testing.releaserTearDown(self)
      
     def test_light_archiving(self):
-        
+
         location = join(os.path.dirname(__file__), 'tarball')
         tarfile_ = join(os.path.dirname(__file__), 'pack.tgz')
+        
+        x = [join(location, path) for path in 
+             ['parts', 'var', 'develop-eggs', 'bin', 'lib',
+              'Lib', 'Scripts', join('downloads', 'dist')]]
 
         # light archiving
-        archive_contents('pack.tgz', location, source=True) 
+        archive_contents('pack.tgz', location, source=True, exclude=x) 
         import tarfile
         tar = tarfile.open(tarfile_, "r:gz")
         try:
@@ -66,6 +70,11 @@ class ProjectTest(unittest.TestCase):
 
         for el in ['downloads/file.pyc', 'file2.pyc', 'file3.pyo']:
             self.assert_(el not in elements)
+        
+        # make sure we don't have downloads/dist files and Scripts/ ones:
+        #for el in ['downloads/dist/file', 'Scripts/a_script']:
+        for el in ['Scripts/a_script']:
+            self.assert_(el not in elements)
 
         os.remove(tarfile_)
 
